import time
import rcpy.motor as motor
from rcpy.motor import motor2
from rcpy.motor import motor3

global duty
duty = 0.8


# TODO get the pyctrl module to work: https://github.com/mcdeoliveira/pyctrl
# This module will replace the rc_balance_dstr.py, and the need to modify rc_balance.c

def move_back(distance_meters = 1):
    global duty
    if duty > 0:
        duty = duty * -1
    move_distance(distance_meters)


def move_forward(distance_meters = 1):
    global duty
    if duty < 0:
        duty = duty * -1
    move_distance(distance_meters)


def move_distance(distance_meters = 1):
    global duty
    motor_left = motor2
    motor_right = motor3

    motor_left.set(duty * 0.5)
    motor_right.set(-duty * 0.5)
    time.sleep(1.35*distance_meters)
    motor_left.set(0)
    motor_right.set(0)
    time.sleep(1)


def turn_right():
    global duty
    if duty < 0:
        duty = duty * -1
    motor_right = motor3
    turn(motor_right)


def turn_left():
    global duty
    if duty > 0:
        duty = duty * -1
    motor_left = motor3
    turn(motor_left)


def turn(motor):
    global duty
    motor.set(duty * 0.5)
    time.sleep(0.3)
    motor.set(0)
    time.sleep(1)


def test(dist = 1):
    move_forward(dist)
    turn_right()
    turn_right()
    move_forward(dist)
    turn_left()
    turn_left()
    move_forward(dist)
    turn_left()
    turn_left()
    move_forward(dist)
    turn_left()
    turn_left()
    move_forward(dist)
    turn_right()
    turn_right()
    turn_right()
    turn_right()
    move_back(dist)




import os
from setuptools import setup
from setuptools import find_packages


def _path(filename):  # noqa: N802
    return os.path.join(os.path.dirname(__file__), filename)


DEFAULT_NAME = "blupants"
DEFAULT_REQS = [
    "Adafruit_BBIO",
    "rcpy"
]

if os.path.exists(_path("pip-requirements.txt")):
    with open(_path("pip-requirements.txt")) as fp:
        reqs = fp.read().strip()
else:
    reqs = DEFAULT_REQS


setup(
    name=DEFAULT_NAME,
    version="1.0.0a1",
    module_name=DEFAULT_NAME,
    python_requires='>=3.4',
    author="BluPants",
    author_email="blupants.robot@gmail.com",
    description="BluPants client module. This module allows your robot to execute commands from the "
                "BluPants Coding Lab (https://blupants.org).",
    url="https://blupants.com",
    package_dir={"": "src/python"},
    packages=find_packages("src/python"),
    license="Apache-2.0",
    install_requires=reqs,
    include_package_data=True,
    scripts=[
        "bin/blupants"
    ]
)



import blupants.blupants_client as blupants_client

global module_name
module_name = ""

def version():
    return "1.0.0a1"


def verbose(verbose_level):
    return verbose_level


def run(module):
    global module_name
    module_name = module
    if module_name == "blupants_client":
        blupants_client.run()


def shutdown():
    global module_name
    module_name = module
    if module_name == "blupants_client":
        blupants_client.shutdown()



import os
import time

# TODO this is a temporary workaround while we can't get pyctrl module to work: https://github.com/mcdeoliveira/pyctrl
# This module will br replaced the edumip.py

"""
This packaged depends on a modified version of the original rc_balance. You will need to modify the
original rc_balance.c and recompile it to make it work. Please follow the instructions below:

https://github.com/StrawsonDesign/librobotcontrol
wget https://raw.githubusercontent.com/blupants/blupants/master/rc_balance.c -O rc_balance.c
git clone https://github.com/StrawsonDesign/librobotcontrol.git
cp ./librobotcontrol/examples/src/rc_balance.c ./librobotcontrol/examples/src/rc_balance.c.ORIGINAL
cp ./rc_balance.c ./librobotcontrol/examples/src/rc_balance.c
cd librobotcontrol
make
cp ./examples/bin/rc_balance /usr/bin/rc_balance_dstr
rc_balance_dstr -i dstr
"""


global turn_coefficient
turn_coefficient = 0.0175

global meter_coefficient
meter_coefficient = 14


global var_dir
var_dir = os.path.join(os.sep, "tmp")


print("Make sure you have eduMPI balanced before running this script.")
print("#rc_balance_dstr -i dstr")


def _create_cmd_file(cmd):
    global var_dir
    file_path = os.path.join(var_dir, cmd)
    open(file_path, 'a').close()


def move_forward(distance_meter = 1.0):
    global meter_coefficient
    print ("Moving forward")
    _create_cmd_file("up.txt.")
    time.sleep(meter_coefficient*distance_meter)
    _create_cmd_file("break.txt.")
    time.sleep(2)


def move_back(distance_meter = 1.0):
    global meter_coefficient
    print("Moving back")
    _create_cmd_file("down.txt.")
    time.sleep(meter_coefficient*distance_meter)
    _create_cmd_file("break.txt.")
    time.sleep(2)


def turn_left(degree = 90.0):
    global turn_coefficient
    print("Turning left")
    _create_cmd_file("left.txt.")
    time.sleep(turn_coefficient*degree)
    _create_cmd_file("break.txt.")
    time.sleep(2)


def turn_right(degree = 90.0):
    global turn_coefficient
    print("Turning right")
    _create_cmd_file("right.txt.")
    time.sleep(turn_coefficient*degree)
    _create_cmd_file("break.txt.")
    time.sleep(2)


def move_block(blocks=1):
    block_size_meters = 0.28
    if blocks > 0:
        move_forward(block_size_meters * blocks)
    else:
        move_back(block_size_meters * (blocks * -1))


def spin_360():
    turn_left()
    turn_left()
    turn_left()
    turn_left()


def kitcken_lap():
    move_forward(1.2)
    turn_left()
    move_forward(2.1)
    turn_left()
    move_forward(1.2)
    turn_left()
    move_forward(2.1)
    turn_left()


def shutdown():
    global running
    running = False


